//
//  ViewController.swift
//  Muelle Amortiguado
//
//  Created by Santiago Pavón on 1/10/15.
//  Copyright © 2015 UPM. All rights reserved.
//

import UIKit

class ViewController: UIViewController, FunctionViewDataSource {
    
    
    @IBOutlet weak var massSlider: UISlider!
    @IBOutlet weak var kSlider: UISlider!
    @IBOutlet weak var λSlider: UISlider!
    
    @IBOutlet weak var speedPosFunctionView: FunctionView!
    @IBOutlet weak var posTimeFunctionView: FunctionView!
    @IBOutlet weak var speedTimeFunctionView: FunctionView!
    
    var springModel: SpringModel!
    
    override func viewDidLoad() {
        super.viewDidLoad()
        
        springModel = SpringModel()
        
        speedPosFunctionView.dataSource = self
        posTimeFunctionView.dataSource = self
        speedTimeFunctionView.dataSource = self
        
        speedPosFunctionView.scaleX = 30.0
        speedPosFunctionView.scaleY = 6.0
        
        posTimeFunctionView.scaleX = 20.0
        posTimeFunctionView.scaleY = 30.0

        speedTimeFunctionView.scaleX = 20.0
        speedTimeFunctionView.scaleY = 6.0
        
        massSlider.sendActions(for: .valueChanged)
        kSlider.sendActions(for: .valueChanged)
        λSlider.sendActions(for: .valueChanged)
    }


    @IBAction func massChanged(_ sender: UISlider) {
        springModel.mass = Double(sender.value)
        
        speedPosFunctionView.setNeedsDisplay()
        posTimeFunctionView.setNeedsDisplay()
        speedTimeFunctionView.setNeedsDisplay()
    }
    
    @IBAction func kChanged(_ sender: UISlider) {
        springModel.k = Double(sender.value)
        
        speedPosFunctionView.setNeedsDisplay()
        posTimeFunctionView.setNeedsDisplay()
        speedTimeFunctionView.setNeedsDisplay()
    }
    
    @IBAction func λChanged(_ sender: UISlider) {
        springModel.λ = Double(sender.value)
        
        speedPosFunctionView.setNeedsDisplay()
        posTimeFunctionView.setNeedsDisplay()
        speedTimeFunctionView.setNeedsDisplay()
    }
    
    // MARK: FunctionViewDataSource

    func startTimeOfFunctionView(_ functionView: FunctionView) -> Double {
        return 0
    }
    
    
    func endTimeOfFunctionView(_ functionView: FunctionView) -> Double {
        return 10
    }
    
    
    func pointOfFunctionView(_ functionView: FunctionView, atTime time: Double) -> Point {
        
        switch functionView {
            
        case speedPosFunctionView:
            let x = springModel.posAtTime(time)
            let y = springModel.speedAtTime(time)
            return Point(x:x, y:y)

        case speedTimeFunctionView:
            let x = time
            let y = springModel.speedAtTime(time)
            return Point(x:x, y:y)
            
        case posTimeFunctionView:
            let x = time
            let y = springModel.posAtTime(time)
            return Point(x:x, y:y)
            
        default:
            return Point(x:0, y:0)
        }
        
    }
}

